/****************************************************************************
** Meta object code from reading C++ file 'statemachineloader_p.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../qtscxml/src/scxmlqml/statemachineloader_p.h"
#include "qscxmlstatemachine.h"
#include "qscxmltabledata.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QProperty>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'statemachineloader_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN24QScxmlStateMachineLoaderE_t {};
} // unnamed namespace

template <> constexpr inline auto QScxmlStateMachineLoader::qt_create_metaobjectdata<qt_meta_tag_ZN24QScxmlStateMachineLoaderE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QScxmlStateMachineLoader",
        "QML.Element",
        "StateMachineLoader",
        "QML.AddedInVersion",
        "1288",
        "sourceChanged",
        "",
        "initialValuesChanged",
        "stateMachineChanged",
        "dataModelChanged",
        "source",
        "QUrl",
        "stateMachine",
        "QScxmlStateMachine*",
        "initialValues",
        "QVariantMap",
        "dataModel",
        "QScxmlDataModel*"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'sourceChanged'
        QtMocHelpers::SignalData<void()>(5, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'initialValuesChanged'
        QtMocHelpers::SignalData<void()>(7, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'stateMachineChanged'
        QtMocHelpers::SignalData<void()>(8, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'dataModelChanged'
        QtMocHelpers::SignalData<void()>(9, 6, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'source'
        QtMocHelpers::PropertyData<QUrl>(10, 0x80000000 | 11, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet | QMC::Bindable, 0),
        // property 'stateMachine'
        QtMocHelpers::PropertyData<QScxmlStateMachine*>(12, 0x80000000 | 13, QMC::Readable | QMC::Scriptable | QMC::Stored | QMC::EnumOrFlag | QMC::Bindable, 2),
        // property 'initialValues'
        QtMocHelpers::PropertyData<QVariantMap>(14, 0x80000000 | 15, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet | QMC::Bindable, 1),
        // property 'dataModel'
        QtMocHelpers::PropertyData<QScxmlDataModel*>(16, 0x80000000 | 17, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet | QMC::Bindable, 3),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<QScxmlStateMachineLoader, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject QScxmlStateMachineLoader::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN24QScxmlStateMachineLoaderE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN24QScxmlStateMachineLoaderE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN24QScxmlStateMachineLoaderE_t>.metaTypes,
    nullptr
} };

void QScxmlStateMachineLoader::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QScxmlStateMachineLoader *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->sourceChanged(); break;
        case 1: _t->initialValuesChanged(); break;
        case 2: _t->stateMachineChanged(); break;
        case 3: _t->dataModelChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (QScxmlStateMachineLoader::*)()>(_a, &QScxmlStateMachineLoader::sourceChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (QScxmlStateMachineLoader::*)()>(_a, &QScxmlStateMachineLoader::initialValuesChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (QScxmlStateMachineLoader::*)()>(_a, &QScxmlStateMachineLoader::stateMachineChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (QScxmlStateMachineLoader::*)()>(_a, &QScxmlStateMachineLoader::dataModelChanged, 3))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 3:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QScxmlDataModel* >(); break;
        case 1:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QScxmlStateMachine* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QUrl*>(_v) = _t->source(); break;
        case 1: *reinterpret_cast<QScxmlStateMachine**>(_v) = _t->stateMachine(); break;
        case 2: *reinterpret_cast<QVariantMap*>(_v) = _t->initialValues(); break;
        case 3: *reinterpret_cast<QScxmlDataModel**>(_v) = _t->dataModel(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setSource(*reinterpret_cast<QUrl*>(_v)); break;
        case 2: _t->setInitialValues(*reinterpret_cast<QVariantMap*>(_v)); break;
        case 3: _t->setDataModel(*reinterpret_cast<QScxmlDataModel**>(_v)); break;
        default: break;
        }
    }
    if (_c == QMetaObject::BindableProperty) {
        switch (_id) {
        case 0: *static_cast<QUntypedBindable *>(_a[0]) = _t->bindableSource(); break;
        case 1: *static_cast<QUntypedBindable *>(_a[0]) = _t->bindableStateMachine(); break;
        case 2: *static_cast<QUntypedBindable *>(_a[0]) = _t->bindableInitialValues(); break;
        case 3: *static_cast<QUntypedBindable *>(_a[0]) = _t->bindableDataModel(); break;
        default: break;
        }
    }
}

const QMetaObject *QScxmlStateMachineLoader::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QScxmlStateMachineLoader::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN24QScxmlStateMachineLoaderE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int QScxmlStateMachineLoader::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 4)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 4;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    return _id;
}

// SIGNAL 0
void QScxmlStateMachineLoader::sourceChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void QScxmlStateMachineLoader::initialValuesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void QScxmlStateMachineLoader::stateMachineChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void QScxmlStateMachineLoader::dataModelChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}
QT_WARNING_POP
