/****************************************************************************
** Meta object code from reading C++ file 'statemachineforeign_p.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../qtscxml/src/statemachineqml/statemachineforeign_p.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'statemachineforeign_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN20QHistoryStateForeignE_t {};
} // unnamed namespace

template <> constexpr inline auto QHistoryStateForeign::qt_create_metaobjectdata<qt_meta_tag_ZN20QHistoryStateForeignE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QHistoryStateForeign",
        "QML.Foreign",
        "QHistoryState",
        "QML.Element",
        "HistoryState",
        "QML.AddedInVersion",
        "256"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
    });
    return QtMocHelpers::metaObjectData<QHistoryStateForeign, void>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject QHistoryStateForeign::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20QHistoryStateForeignE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20QHistoryStateForeignE_t>.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN20QHistoryStateForeignE_t>.metaTypes,
    nullptr
} };

namespace {
struct qt_meta_tag_ZN13QStateForeignE_t {};
} // unnamed namespace

template <> constexpr inline auto QStateForeign::qt_create_metaobjectdata<qt_meta_tag_ZN13QStateForeignE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QStateForeign",
        "QML.Foreign",
        "QState",
        "QML.Element",
        "QML.AddedInVersion",
        "256",
        "QML.Creatable",
        "false",
        "QML.UncreatableReason",
        "Don't use this, use State instead."
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    2 },
            {    4,    5 },
            {    6,    7 },
            {    8,    9 },
    });
    return QtMocHelpers::metaObjectData<QStateForeign, void>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject QStateForeign::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13QStateForeignE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13QStateForeignE_t>.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN13QStateForeignE_t>.metaTypes,
    nullptr
} };

namespace {
struct qt_meta_tag_ZN21QAbstractStateForeignE_t {};
} // unnamed namespace

template <> constexpr inline auto QAbstractStateForeign::qt_create_metaobjectdata<qt_meta_tag_ZN21QAbstractStateForeignE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QAbstractStateForeign",
        "QML.Foreign",
        "QAbstractState",
        "QML.Element",
        "QML.AddedInVersion",
        "256",
        "QML.Creatable",
        "false",
        "QML.UncreatableReason",
        "Don't use this, use State instead."
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    2 },
            {    4,    5 },
            {    6,    7 },
            {    8,    9 },
    });
    return QtMocHelpers::metaObjectData<QAbstractStateForeign, void>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject QAbstractStateForeign::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21QAbstractStateForeignE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21QAbstractStateForeignE_t>.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN21QAbstractStateForeignE_t>.metaTypes,
    nullptr
} };

namespace {
struct qt_meta_tag_ZN24QSignalTransitionForeignE_t {};
} // unnamed namespace

template <> constexpr inline auto QSignalTransitionForeign::qt_create_metaobjectdata<qt_meta_tag_ZN24QSignalTransitionForeignE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QSignalTransitionForeign",
        "QML.Foreign",
        "QSignalTransition",
        "QML.Element",
        "QML.AddedInVersion",
        "256",
        "QML.Creatable",
        "false",
        "QML.UncreatableReason",
        "Don't use this, use SignalTransition instead."
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    2 },
            {    4,    5 },
            {    6,    7 },
            {    8,    9 },
    });
    return QtMocHelpers::metaObjectData<QSignalTransitionForeign, void>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject QSignalTransitionForeign::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN24QSignalTransitionForeignE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN24QSignalTransitionForeignE_t>.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN24QSignalTransitionForeignE_t>.metaTypes,
    nullptr
} };

QT_WARNING_POP
